import React, {useEffect, useState} from "react";
import {useRouter} from "next/router";
import Layout from "../components/Layout";
import Link from "next/link";
import classNames from "classnames";

export default function Search() {
    const router = useRouter();

    const [token, setToken] = useState("");
    const [search, setSearch] = useState("");
    const [menuItems, setMenuItems] = useState([
        {id: 1, label: "", link: "/", first: "", bold: "", second: ""}
    ]);

    useEffect(() => {
        setToken(() => localStorage.getItem("token"))
    }, [])

    const handleSubmit = async (event) => {
        event.preventDefault()

        const res = await fetch("http://localhost:8000/api/documents?" + new URLSearchParams(
            {query: "*" + event.target.search.value + "*"}
        ), {
            method: "GET",
            headers: {
                'Authorization': `Bearer ${token}`
            }
        })
        let json = await res.json();
        let list = []
        json.forEach((doc) => {
            let highlight = doc["highlight"].replaceAll('\'', '').replaceAll('[', '').replaceAll(']', '')
            let initial = highlight.indexOf('<em>')
            let end = highlight.indexOf('</em>')
            let first_str, second_str
            if (highlight.length < end + 15) {
                second_str = highlight.substring(end, highlight.length)
            } else {
                second_str = highlight.substring(end, end + 15) + " ..."
            }
            if (initial - 10 < 0) {
                first_str = highlight.substring(0, initial)
            } else {
                first_str = "... " + highlight.substring(initial - 10, initial)
            }
            highlight = highlight.substring(initial + 4, end)
            list.push({
                id: doc["id"],
                label: doc["name"],
                first: first_str.replace('<em>', ''),
                bold: highlight,
                second: second_str.replace('</em>', ''),
                link: `/documents/${doc["id"]}`
            })
        })

        setMenuItems(() => list)
    }

    return (
        <Layout>
            <form onSubmit={handleSubmit}>
                <input type="text" id="search" name="search" required style={{color: "black", padding: "2px 4px"}}/>

                <button type="submit">Search</button>
            </form>

            {menuItems && (
                <div className="flex flex-col items-start mt-24">
                    {menuItems.map(({...menu}) => {
                        return (
                            <div key={menu.id}>
                                <span>

                                <Link href={menu.link}>
                                    <a className="flex py-4 px-3 items-center w-full h-full">
                                        <div style={{width: "2.5rem"}}>
                                        </div>
                                        <span
                                            className={classNames(
                                                "text-md font-medium text-text-light"
                                            )}
                                        >
                                            {menu.label}
                                        </span>
                                    </a>
                                </Link>
                                    <p>{menu.first}<b>{menu.bold}</b>{menu.second}</p>
                                </span>
                            </div>
                        );
                    })}
                </div>
            )}

        </Layout>
    );
}